/*****************************************************************************/
/* SPSSload_NEDS_2016_Hospital.SPS                                          */
/* This program will load the NEDS 2016 Hospital csv File into SPSS.         */
/*****************************************************************************/

/* Read data elements from the csv file */
get data /type = txt
    /file = "NEDS_2016_Hospital.csv"
    /delimiters = ',' 
    /variables = 
    DISCWT                   F11.7
    HOSPWT                   F11.7
    HOSP_CONTROL             F2.0
    HOSP_ED                  F5.0
    HOSP_REGION              F2.0
    HOSP_TRAUMA              F2.0
    HOSP_URCAT4              F2.0
    HOSP_UR_TEACH            F2.0
    NEDS_STRATUM             F5.0
    N_DISC_U                 F8.0
    N_HOSP_U                 F4.0
    S_DISC_U                 F8.0
    S_HOSP_U                 F4.0
    TOTAL_EDVisits           F8.0
    YEAR                     F4.0
.

/*  Assign labels to the data elements */
VARIABLE LABELS 
    DISCWT                   "Weight to ED Visits in AHA universe"
    HOSPWT                   "Weight to hospitals in AHA universe"
    HOSP_CONTROL             "Control/ownership of hospital"
    HOSP_ED                  "HCUP ED hospital identifier"
    HOSP_REGION              "Region of hospital"
    HOSP_TRAUMA              "Trauma level designation"
    HOSP_URCAT4              "Hospital urban-rural designation"
    HOSP_UR_TEACH            "Teaching status of hospital"
    NEDS_STRATUM             "Stratum used to sample hospital"
    N_DISC_U                 "Number of AHA universe ED visits in NEDS_STRATUM"
    N_HOSP_U                 "Number of AHA universe hospitals in NEDS_STRATUM"
    S_DISC_U                 "Number of sample discharges in NEDS_STRATUM"
    S_HOSP_U                 "Number of sample hospitals in NEDS_STRATUM"
    TOTAL_EDVisits           "Total number of ED visits from this hospital in the NEDS"
    YEAR                     "Calendar Year" .

/* Convert special values to system missing values */
RECODE DISCWT                   (-99.9999999 -88.8888888 -66.6666666=SYSMIS).
RECODE HOSPWT                   (-99.9999999 -88.8888888 -66.6666666=SYSMIS).
RECODE HOSP_CONTROL             (-9 -8 -6 -5=SYSMIS).
RECODE HOSP_ED                  (-9999 -8888 -6666=SYSMIS).
RECODE HOSP_REGION              (-9 -8 -6 -5=SYSMIS).
RECODE HOSP_TRAUMA              (-9 -8 -6 -5=SYSMIS).
RECODE HOSP_URCAT4              (-9 -8 -6 -5=SYSMIS).
RECODE HOSP_UR_TEACH            (-9 -8 -6 -5=SYSMIS).
RECODE NEDS_STRATUM             (-9999 -8888 -6666=SYSMIS).
RECODE N_DISC_U                 (-9999999 -8888888 -6666666=SYSMIS).
RECODE N_HOSP_U                 (-999 -888 -666=SYSMIS).
RECODE S_DISC_U                 (-9999999 -8888888 -6666666=SYSMIS).
RECODE S_HOSP_U                 (-999 -888 -666=SYSMIS).
RECODE TOTAL_EDVisits           (-9999999 -8888888 -6666666=SYSMIS).
RECODE YEAR                     (-999 -888 -666=SYSMIS).

SAVE OUTFILE = 'NEDS_2016_Hospital.SAV' / COMPRESSED.
